@@ -4,13 +4,15 @@ package version::vxs;
 use 5.005_03;
 use strict;
 
+require Exporter;
 require DynaLoader;
-use vars qw(@ISA $VERSION $CLASS );
+use vars qw(@ISA $VERSION $CLASS @EXPORT);
 
-@ISA = qw(DynaLoader);
+@ISA = qw(Exporter DynaLoader);
 
-$VERSION = "0.59_05";
-$VERSION = eval $VERSION;
+@EXPORT = qw(qv);
+
+$VERSION = $version::VERSION;
 
 $CLASS = 'version::vxs';
 
